==> kdelibs-3.4.1.tar.bz2: kdelibs-3.4.1/khtml/rendering/render_generated.h <==
/*
 * This file is part of the HTML rendering engine for KDE.
 *
 * Copyright (C) 2004 Allan Sandfeld Jensen (kde@carewolf.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 */
#ifndef RENDER_GENERATED_H
#define RENDER_GENERATED_H

#include "rendering/render_text.h"

namespace DOM {
    class CounterImpl;
}

namespace khtml {
    class CounterNode;

// -----------------------------------------------------------------------------

class RenderCounter : public RenderText
{
public:
    RenderCounter(DOM::NodeImpl* node, const DOM::CounterImpl* counter);
    virtual ~RenderCounter() {};

    virtual const char *renderName() const { return "RenderCounter"; }

    virtual void layout( );
    virtual void calcMinMaxWidth();

protected:
    QString toListStyleType(int value, int total, EListStyleType type);

    QString m_item;
    const DOM::CounterImpl* m_counter;
    CounterNode *m_counterNode;
};

} //namespace

#endif

==> kdelibs-3.5.1.tar.bz2: kdelibs-3.5.1/khtml/rendering/render_generated.h <==
/*
 * This file is part of the HTML rendering engine for KDE.
 *
 * Copyright (C) 2004,2005 Allan Sandfeld Jensen (kde@carewolf.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */
#ifndef RENDER_GENERATED_H
#define RENDER_GENERATED_H

#include "rendering/render_text.h"

namespace DOM {
    class CounterImpl;
}

namespace khtml {
    class CounterNode;

// -----------------------------------------------------------------------------

class RenderCounterBase : public RenderText
{
public:
    RenderCounterBase(DOM::NodeImpl* node);

    virtual const char *renderName() const { return "RenderCounterBase"; }

    virtual void layout( );
    virtual void calcMinMaxWidth();
    virtual bool isCounter() const { return true; }

    virtual void generateContent() = 0;
    void updateContent();

protected:
    QString m_item;
    CounterNode *m_counterNode; // Cache of the counternode
};

// -----------------------------------------------------------------------------

class RenderCounter : public RenderCounterBase
{
public:
    RenderCounter(DOM::NodeImpl* node, const DOM::CounterImpl* counter);
    virtual ~RenderCounter() {};

    virtual const char *renderName() const { return "RenderCounter"; }

    virtual void generateContent();

protected:
    QString toListStyleType(int value, int total, EListStyleType type);

    const DOM::CounterImpl* m_counter;
};

// -----------------------------------------------------------------------------

class RenderQuote : public RenderCounterBase
{
public:
    RenderQuote(DOM::NodeImpl* node, EQuoteContent type);
    virtual ~RenderQuote() {};

    virtual const char *renderName() const { return "RenderQuote"; }

    virtual bool isQuote() const { return true; }
    virtual int quoteCount() const;

    virtual void generateContent();

protected:
    EQuoteContent m_quoteType;
};

} //namespace

#endif
